function [Ceqdef,Jacdef] = DefReact(nvar,into,colind,scl,def)

%
% Written by Julian Straus, Trondheim 09.12.2018
% 
% This function defines the definition values in the reaction
% section of the simple ammonia loop. It can be modified to define the
% flowsheet differently. The definitions in this file are given by:
%
%   Cold inlet HEx2     Q, p, T, and xi
%
% The input of this function is given by
%       nvar:   Total number of variables.
%
%       into:   Input values to the unit operation defined in the
%               flowsheet.
%
%       colind: Indexes of the columns i the Jacobian.
%
% The main output is defined as
%       Ceqdef: Cells containing the equality constraints of the
%               definitions.
%
%       Jacdef: Cells containing the rows of the Jacobian defined by the
%               definitions.
%
% The necessary structures and cells are defined as
%       scl:    Scaling factors of the system defined in cells representing
%               the unit operations defined in par.ReactSec.
%
%       def:    Defined stream values, e.g pressure and composition for all
%               inlets and the pressure of the outlets or the flow of the
%               inlets.

% Predefinition of the returning cells.
Jacdef = cell(size(into));
Ceqdef = Jacdef;
                                  
%% Definitions in Heat Exchanger 2

k = 1;
% Calculation of the equality constraints for the definition of heat exchanger 2
Ceqdef{k+1} = (into{k}(17:24).*scl{k}.Var(17:24)'-def.FReact).*scl{k}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% heat exchanger 2
colind{k+1} = colind{k}(17:24);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq'.*scl{k}.Var(17:24),...
                     numel(Ceqdef{k+1}),nvar);
                                  
%% Definitions in Split 1

k = 3;
% Calculation of the equality constraints for the definition of split 1
Ceqdef{k+1} = (into{k}(33:34).*scl{k}.Var(33:34)'-def.Sratio{1}(1:2)).*scl{k}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% split 1
colind{k+1} = colind{k}(33:34);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq'.*scl{k}.Var(33:34),...
                     numel(Ceqdef{k+1}),nvar);
                                  
%% Definitions in Heat Exchanger 5

k = 17;
% Calculation of the equality constraints for the definition of heat exchanger 5
Ceqdef{k+1} = (into{k}(9).*scl{k}.Var(9)'-def.Tref).*scl{k}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% heat exchanger 5
colind{k+1} = colind{k}(9);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq'.*scl{k}.Var(9),...
                     numel(Ceqdef{k+1}),nvar);
